"use client";

import React, { useCallback } from "react";
import Image from "next/image";
import Particles from "react-tsparticles";
import type { Engine } from "tsparticles-engine";
import { loadFull } from "tsparticles";
import Stack from "./Stack";

const Hero: React.FC = () => {
  const particlesInit = useCallback(async (engine: Engine) => {
    await loadFull(engine);
  }, []);

  return (
    <div className="md:h-[540px] lg:h-[540px]">
      <div className="relative w-full  flex items-center">
        {/* Confined Particles Background */}
        <div className="absolute inset-0 w-full h-full pointer-events-none">
          <Particles
            id="tsparticles"
            init={particlesInit}
            className="absolute inset-0"
            options={{
              background: { color: "transparent" },
              fullScreen: { enable: false }, // This prevents particles from taking up the whole page
              particles: {
                color: { value: "#398D9C" }, // Red particles
                number: { value: 80, density: { enable: true, area: 800 } },
                shape: { type: "circle" },
                opacity: { value: 0.5 },
                size: { value: 3 },
                move: { enable: true, speed: 1 },
                links: { enable: true, color: "#398D9C", opacity: 10 },
              },
              interactivity: {
                events: {
                  onHover: { enable: true, mode: "repulse" },
                  onClick: { enable: true, mode: "push" },
                },
                modes: {
                  repulse: { distance: 100 },
                  push: { particles_nb: 4 },
                },
              },
            }}
          />
        </div>

        {/* Hero Content */}
        <div className="relative z-10 flex flex-col md:flex-row lg:flex-row w-full pt-1 pl-5 pr-5">
          <div className="flex-1 flex flex-col justify-center md:pl-[80px] lg:pl-[80px] gap-5">
            <h2 className="md:text-[24px] lg:text-[24px] text-[18px] text-[#4F4F4F] font-semibold mt-[100px] md:mt-0 lg:mt-0">
              A SOFTWARE DEVELOPMENT COMPANY
            </h2>
            <h1 className="text-black md:text-[44px] lg:text-[44px] text-[35px] font-semibold pr-5">
              We partner with Industry Experts to solve Logistical and
              Productivity problems
            </h1>
            <h2 className="md:text-[30px] lg:text-[30px] text-[18px] text-[#4F4F4F] font-medium">
              Let’s Build a Great Idea.
            </h2>
          </div>
          <div className="flex-1 pt-5 z-50 hidden md:flex lg:flex">
            <Image
              src="/Graphic.png"
              height={500}
              width={700}
              alt="Graphic representing the company's work"
              priority
            />
          </div>
          <div className="flex-1 pt-5 z-50 md:hidden lg:hidden mt-5">
            <Image
              src="/Graphic.png"
              height={600}
              width={800}
              alt="Graphic representing the company's work"
              priority
            />
          </div>
        </div>
      </div>
    </div>
  );
};

export default Hero;
